# Date range Filter

Date range Filter is a Dash component library.

This is a dash datetime range picker based on React Advanced Date Time Range Picker
. In contrast to the dash datepicker from dash-core-components, it is also possible to specify hours and minutes on a certain day.

Get started with:
1. Install Dash and its dependencies: https://dash.plotly.com/installation
2. Run `python usage.py`
3. Visit http://localhost:8050 in your web browser

## Contributing

See [CONTRIBUTING.md](./CONTRIBUTING.md)

### Install dependencies

If you have selected install_dependencies during the prompt, you can skip this part.

    ```
1. Create a virtual env and activate.
    ```
    $ virtualenv venv
    $ . venv/bin/activate
    ```
    _Note: venv\Scripts\activate for windows_

2. Install python packages required to build components.
    ```
    $ pip install -r requirements.txt
    ```
3. Install the python packages for testing (optional)
    ```
    $ pip install -r tests/requirements.txt
    ```

